==> leonardo-0.4.0-rc1.tgz: leonardo-0.4.0-rc1/lib/providers/static.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from web_resource import TopLevelResource


    
class StaticFileProvider:
    
    
    def __init__(self, config):
        
        self.static_dir      = config.static_dir
        
        
    def get(self, resource_id, request, main_resource):

        if resource_id[:4] not in ["1996", "1997", "1998", "1999", "2000",
        "2001", "2002", "2003", "2004", "2005"]:
            return None

        path = resource_id
        
        if path[-1] == "/":
            path += "index.html" # @@@ should extend this to other filenames
        path = path.strip("/")
        ext = path[path.rfind("."):]
        if ext in [".htm", ".html"]:
            mime_type = "text/html"
        elif ext in [".jpg", ".jpeg"]:
            mime_type = "image/jpeg"
        elif ext in [".css"]:
            mime_type = "text/css"
        else:
            mime_type = "text/plain"
        
        try:
            f = file(self.static_dir + path, "rb")
            x = f.read()
            f.close()
            return StaticFile(path, x, mime_type)
        except:
            return StaticFile404(path)
            
            

class StaticFile(TopLevelResource):

    
    def __init__(self, resource_id, content, mime_type):
        TopLevelResource.__init__(self, resource_id, mime_type)
        self.content = content
        
        
    def exists(self):
        return True
       

    def get_content(self):
        return self.content
   
    
    def get_lastmod(self):
        # @@@
        return 0
        
        
    def is_read_only(self):
        return True # @@@ for now    

        
        
class StaticFile404(StaticFile):

    
    def __init__(self, resource_id):
        StaticFile.__init__(resource_id, "File Not Found.", "text/plain")
        self.status = "404 Not Found"


    def exists(self):
        return False

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/providers/static.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from web_resource import TopLevelResource


    
class StaticFileProvider:
    
    
    def __init__(self, config):
        
        self.static_dir      = config.static_dir
        
        
    def get(self, resource_id, request, main_resource):

        if resource_id[:4] not in ["1996", "1997", "1998", "1999", "2000",
        "2001", "2002", "2003", "2004", "2005"]:
            return None

        path = resource_id
        
        if path[-1] == "/":
            path += "index.html" # @@@ should extend this to other filenames
        path = path.strip("/")
        ext = path[path.rfind("."):]
        if ext in [".htm", ".html"]:
            mime_type = "text/html"
        elif ext in [".jpg", ".jpeg"]:
            mime_type = "image/jpeg"
        elif ext in [".css"]:
            mime_type = "text/css"
        else:
            mime_type = "text/plain"
        
        try:
            f = file(self.static_dir + path, "rb")
            x = f.read()
            f.close()
            return StaticFile(path, x, mime_type)
        except:
            return StaticFile404(path)
            
            

class StaticFile(TopLevelResource):

    
    def __init__(self, resource_id, content, mime_type):
        TopLevelResource.__init__(self, resource_id, mime_type)
        self.content = content
        
        
    def exists(self):
        return True
       

    def get_content(self):
        return self.content
   
    
    def get_lastmod(self):
        # @@@
        return 0
        
        
    def is_read_only(self):
        return True # @@@ for now    

        
        
class StaticFile404(StaticFile):

    
    def __init__(self, resource_id):
        StaticFile.__init__(self, resource_id, "File Not Found.", "text/plain")
        self.status = "404 Not Found"


    def exists(self):
        return False
